============
businesstime
============

.. image:: https://travis-ci.org/seatgeek/businesstime.png?branch=master
        :target: https://travis-ci.org/seatgeek/businesstime

BusinessTime is a simple utility for calculating business time aware timedeltas between two datetimes. It also exposes weekend and holiday aware date iterators and predicate functions for determining whether a given datetime is during business hours or not. BusinessTime's understanding of weekends and holidays can be easily configured in code.